import type { ApolloServerPlugin, GraphQLRequestContextWillSendResponse } from '@apollo/server';
import { type GraphQLContext, type LoggerLogFunctions } from '@makerx/graphql-core';
import type { Logger } from '@makerx/node-common';
export interface GraphQLOperationLoggingPluginOptions<TContext extends GraphQLContext<TLogger, any, any>, TLogger extends Logger = Logger> {
    /**
     * This level will be used to log operations via the logging method of the specified key (default: `info`)
     */
    logLevel?: keyof LoggerLogFunctions<TLogger>;
    /***
     * If provided, this logger will be used to log context creation failures as errors
     */
    contextCreationFailureLogger?: Logger;
    /***
     * If provided, will be bound to the plugin contextCreationDidFail hook, to log or otherwise react to context creation failures.
     * You may provide this option in addition to the contextCreationFailureLogger, both will be called.
     */
    contextCreationDidFail?: ApolloServerPlugin['contextCreationDidFail'];
    /***
     * If provided, this function will be called to determine whether to ignore logging for a given response
     */
    shouldIgnore?: (ctx: GraphQLRequestContextWillSendResponse<TContext>) => boolean;
    /**
     * If true, introspection queries will not be logged (default: `true`)
     */
    ignoreIntrospectionQueries?: boolean;
    /**
     * If true, the response data will be logged for queries and mutations
     */
    includeResponseData?: boolean;
    /**
     * If true, the response data will be logged for mutations
     */
    includeMutationResponseData?: boolean;
    /**
     * Can be used to adjust the variables before logging, e.g. redacting sensitive data
     */
    adjustVariables?: (variables: Record<string, any>) => Record<string, any>;
    /**
     * Can be used to adjust the result data before logging, e.g. redacting sensitive data
     */
    adjustResultData?: (data: Record<string, any>) => Record<string, any>;
    /**
     * Can be used to augment the log entry with additional properties
     */
    augmentLogEntry?: (ctx: TContext) => Record<string, any>;
}
/**
 * This plugin logs GraphQL operations and context creation failure (if specified via options).
 * See options for more details.
 */
export declare function graphqlOperationLoggingPlugin<TContext extends GraphQLContext<TLogger, any, any>, TLogger extends Logger = Logger>({ logLevel, contextCreationDidFail, contextCreationFailureLogger, shouldIgnore, ignoreIntrospectionQueries, includeResponseData, includeMutationResponseData, adjustVariables, adjustResultData, augmentLogEntry, }?: GraphQLOperationLoggingPluginOptions<TContext, TLogger>): ApolloServerPlugin<TContext>;
