import type { ApolloServerPlugin, GraphQLRequestContextWillSendResponse } from '@apollo/server';
import type { GraphQLContext } from '@makerx/graphql-core';
import type { Logger } from '@makerx/node-common';
import type { GraphQLFormattedError } from 'graphql';
export interface GraphQLRequestInfo<TContext extends GraphQLContext<any, any, any>> {
    readonly requestContext: GraphQLRequestContextWillSendResponse<TContext>;
    readonly isSubsequentPayload: boolean;
    readonly formattedErrors?: ReadonlyArray<GraphQLFormattedError>;
}
export interface LoggingPluginOptions<TContext extends GraphQLContext<any, any, any>> {
    /***
     * If provided, this logger will be used to log context creation failures as errors
     */
    contextCreationFailureLogger?: Logger;
    /***
     * If provided, will be bound to the plugin contextCreationDidFail hook to log or otherwise react to context creation failures
     */
    contextCreationDidFail?: ApolloServerPlugin['contextCreationDidFail'];
    /***
     * If provided, this function will be called to determine whether to ignore logging for a given request
     */
    shouldIgnore?: (request: GraphQLRequestInfo<TContext>) => boolean;
}
/**
 * @deprecated use graphqlOperationLoggingPlugin() instead (more options, breaking changes)
 */
export declare function createLoggingPlugin<TContext extends GraphQLContext<TLogger, any, any>, TLogger extends Logger = Logger>(options?: LoggingPluginOptions<TContext>): ApolloServerPlugin<TContext>;
/**
 * @deprecated use createLoggingPlugin() directly instead
 */
export declare const loggingPlugin: ApolloServerPlugin<GraphQLContext>;
