import { User } from '@makerx/graphql-core';

/**
 * A basic RequestInfo constant suitable for test GraphQL contexts (which expect `RequestInfo` but have no HTTP request to build one).
 */
const testRequestInfo = {
    protocol: 'http',
    host: 'localhost',
    url: 'http://localhost/graphql',
    method: 'POST',
    origin: 'test-origin',
    requestId: 'test-request',
};
/**
 * A no-op logger suitable for test GraphQL contexts if you wish to avoid using a real logger.
 */
const noOpLogger = {
    debug: () => { },
    verbose: () => { },
    info: () => { },
    warn: () => { },
    error: () => { },
};
/**
 * Builds a basic GraphQLContext for testing purposes using the supplied JWT payload.
 */
async function createTestContext(jwtPayload) {
    const user = jwtPayload ? new User(jwtPayload, '') : undefined;
    return {
        logger: noOpLogger,
        requestInfo: testRequestInfo,
        user,
        started: Date.now(),
    };
}

export { createTestContext, noOpLogger };
//# sourceMappingURL=context.mjs.map
