'use strict';

/***
 * Returns an `executeOperation` function for the provided ApolloServer instance and context creation function.
 * The returned function accepts a GraphQL request as the first argument followed by context creation function arguments.
 */
function buildExecuteOperation(server, createContext) {
    return async function executeOperation(request, ...createContextArgs) {
        const response = await server.executeOperation(request, {
            contextValue: await createContext(...createContextArgs),
        });
        if (response.body.kind !== 'single')
            throw new Error('Incremental responses are not supported by this testing utility function');
        return response.body.singleResult;
    };
}

exports.buildExecuteOperation = buildExecuteOperation;
//# sourceMappingURL=execute-operation.js.map
