'use strict';

var node_crypto = require('node:crypto');

/**
 *
 * @param Optional JWT input
 * @returns A JWT payload with oid, tid and sub claims set to random values if not provided
 */
function buildJwt({ oid = node_crypto.randomUUID(), tid = node_crypto.randomUUID(), sub = node_crypto.randomUUID(), scopes = [], roles = [], ...rest } = {}) {
    return {
        oid,
        tid,
        sub,
        scp: scopes.join(' '),
        roles,
        ...rest,
    };
}
/**
 *
 * @param Optional JWT input
 * @returns A JWT payload with oid, tid, sub and email claims set to random values if not provided
 */
function buildUserJwt({ email = randomEmail(), ...rest } = {}) {
    return buildJwt({
        email,
        ...rest,
    });
}
function randomEmail() {
    return `${(Math.random() + 1).toString(36).substring(2)}@test.net`;
}

exports.buildJwt = buildJwt;
exports.buildUserJwt = buildUserJwt;
exports.randomEmail = randomEmail;
//# sourceMappingURL=jwt.js.map
